==> guarana-1.0.tar.gz: guarana-1.0/guarana.unicamp.br/external_wrappers.h <==
/*
 * external_wrappers.h
 * Non-shared library wrapper for guarana.unicamp.br package.
 *
 * Copyright 1997,1998 Alexandre Oliva <oliva@dcc.unicamp.br>
 */

/* guarana.unicamp.br/APIguarana */

KAFFE_NATIVE(BR_unicamp_Guarana_Guarana_deliver)
KAFFE_NATIVE(BR_unicamp_Guarana_Guarana_getMetaObjectOf)
KAFFE_NATIVE(BR_unicamp_Guarana_Guarana_setMetaObjectOf)
KAFFE_NATIVE(BR_unicamp_Guarana_Guarana_makeProxy)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_validate)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_getObject)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_getThread)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_getType)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_isClassOperation)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_getOpType)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_isMethodInvocation)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_getMethod)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_isConstructorInvocation)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_getConstructor)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_getArguments)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_isSynchronization)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_isMonitorEnter)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_isMonitorExit)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_isReadOperation)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_isWriteOperation)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_isFieldOperation)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_getField)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_isArrayOperation)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_isArrayLengthOperation)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_getArrayIndex)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_getValue)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_isReplacement)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_getReplaced)
KAFFE_NATIVE(BR_unicamp_Guarana_OperationFactoryInternal_getObject)
KAFFE_NATIVE(BR_unicamp_Guarana_OperationFactoryInternal_invoke)
KAFFE_NATIVE(BR_unicamp_Guarana_OperationFactoryInternal_construct)
KAFFE_NATIVE(BR_unicamp_Guarana_OperationFactoryInternal_monitorEnter)
KAFFE_NATIVE(BR_unicamp_Guarana_OperationFactoryInternal_monitorExit)
KAFFE_NATIVE(BR_unicamp_Guarana_OperationFactoryInternal_read)
KAFFE_NATIVE(BR_unicamp_Guarana_OperationFactoryInternal_write)
KAFFE_NATIVE(BR_unicamp_Guarana_OperationFactoryInternal_length)
KAFFE_NATIVE(BR_unicamp_Guarana_OperationFactoryInternal_readElement)
KAFFE_NATIVE(BR_unicamp_Guarana_OperationFactoryInternal_writeElement)
KAFFE_NATIVE(BR_unicamp_Guarana_Result_returnObject)
KAFFE_NATIVE(BR_unicamp_Guarana_Result_throwObject)
KAFFE_NATIVE(BR_unicamp_Guarana_Result_getOperation)
KAFFE_NATIVE(BR_unicamp_Guarana_Result_isException)
KAFFE_NATIVE(BR_unicamp_Guarana_Result_getValue)

==> guarana-1.1.tar.gz: guarana-1.1/guarana.unicamp.br/external_wrappers.h <==
/*
 * external_wrappers.h
 * Non-shared library wrapper for guarana.unicamp.br package.
 *
 * Copyright 1997,1998 Alexandre Oliva <oliva@dcc.unicamp.br>
 */

/* guarana.unicamp.br/APIguarana */

KAFFE_NATIVE(BR_unicamp_Guarana_Guarana_deliver)
KAFFE_NATIVE(BR_unicamp_Guarana_Guarana_getMetaObjectOf)
KAFFE_NATIVE(BR_unicamp_Guarana_Guarana_setMetaObjectOf)
KAFFE_NATIVE(BR_unicamp_Guarana_Guarana_makeProxy)
KAFFE_NATIVE(BR_unicamp_Guarana_Guarana_hashCode)
KAFFE_NATIVE(BR_unicamp_Guarana_Guarana_getClass)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_validate)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_getObject)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_getThread)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_getType)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_isClassOperation)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_getOpType)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_isMethodInvocation)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_getMethod)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_isConstructorInvocation)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_getConstructor)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_getArguments)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_isSynchronization)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_isMonitorEnter)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_isMonitorExit)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_isReadOperation)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_isWriteOperation)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_isFieldOperation)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_getField)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_isArrayOperation)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_isArrayLengthOperation)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_getArrayIndex)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_getValue)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_isReplacement)
KAFFE_NATIVE(BR_unicamp_Guarana_Operation_getReplaced)
KAFFE_NATIVE(BR_unicamp_Guarana_OperationFactoryInternal_getObject)
KAFFE_NATIVE(BR_unicamp_Guarana_OperationFactoryInternal_nop)
KAFFE_NATIVE(BR_unicamp_Guarana_OperationFactoryInternal_invoke)
KAFFE_NATIVE(BR_unicamp_Guarana_OperationFactoryInternal_construct)
KAFFE_NATIVE(BR_unicamp_Guarana_OperationFactoryInternal_monitorEnter)
KAFFE_NATIVE(BR_unicamp_Guarana_OperationFactoryInternal_monitorExit)
KAFFE_NATIVE(BR_unicamp_Guarana_OperationFactoryInternal_read)
KAFFE_NATIVE(BR_unicamp_Guarana_OperationFactoryInternal_write)
KAFFE_NATIVE(BR_unicamp_Guarana_OperationFactoryInternal_length)
KAFFE_NATIVE(BR_unicamp_Guarana_OperationFactoryInternal_readElement)
KAFFE_NATIVE(BR_unicamp_Guarana_OperationFactoryInternal_writeElement)
KAFFE_NATIVE(BR_unicamp_Guarana_Result_returnObject)
KAFFE_NATIVE(BR_unicamp_Guarana_Result_throwObject)
KAFFE_NATIVE(BR_unicamp_Guarana_Result_getOperation)
KAFFE_NATIVE(BR_unicamp_Guarana_Result_isException)
KAFFE_NATIVE(BR_unicamp_Guarana_Result_getValue)
